==> cmr-http-kit-0.1.5-20181108.174706-2.jar: META-INF/leiningen/gov.nasa.earthdata/cmr-http-kit/README.md <==
# cmr-http-kit

*Utilities, wrappers, middleware, and components for http-kit interop*

[![Build Status][travis-badge]][travis]
[![Security Scan][security-scan-badge]][travis]
[![Dependencies Status][deps-badge]][travis]
[![Open Pull Requests][prs-badge]][prs]

[![Clojars Project][clojars-badge]][clojars]
[![Tag][tag-badge]][tag]

[![Clojure version][clojure-v]](project.clj)

[![][logo]][logo]


## About

This repo just contains utility and wrapper functions common to several CMR
projects which take advantage of http-kit's perfornance and the small size of
its library.


## Dependencies [&#x219F;](#contents)

* Java
* `lein`


## License [&#x219F;](#contents)

Copyright © 2018 NASA

Distributed under the Apache License, Version 2.0.


<!-- Named page links below: /-->

[logo]: https://avatars2.githubusercontent.com/u/32934967?s=200&v=4
[travis]: https://travis-ci.org/cmr-exchange/cmr-http-kit
[travis-badge]: https://travis-ci.org/cmr-exchange/cmr-http-kit.png?branch=master
[deps-badge]: https://img.shields.io/badge/deps%20check-passing-brightgreen.svg
[tag-badge]: https://img.shields.io/github/tag/cmr-exchange/cmr-http-kit.svg
[tag]: https://github.com/cmr-exchange/cmr-http-kit/tags
[clojure-v]: https://img.shields.io/badge/clojure-1.9.0-blue.svg
[clojars]: https://clojars.org/gov.nasa.earthdata/cmr-http-kit
[clojars-badge]: https://img.shields.io/clojars/v/gov.nasa.earthdata/cmr-http-kit.svg
[security-scan-badge]: https://img.shields.io/badge/nvd%2Fsecurity%20scan-passing-brightgreen.svg
[prs]: https://github.com/pulls?utf8=%E2%9C%93&q=is%3Aopen+is%3Apr+org%3Acmr-exchange+archived%3Afalse+
[prs-badge]: https://img.shields.io/badge/Open%20PRs-org-yellow.svg

==> cmr-http-kit-0.3.0.jar: META-INF/leiningen/gov.nasa.earthdata/cmr-http-kit/README.md <==
# cmr-http-kit

*Utilities, wrappers, middleware, and components for http-kit interop*

[![Build Status][travis-badge]][travis]
[![Security Scan][security-scan-badge]][travis]
[![Dependencies Status][deps-badge]][travis]
[![Open Pull Requests][prs-badge]][prs]

[![Clojars Project][clojars-badge]][clojars]
[![Tag][tag-badge]][tag]

[![Clojure version][clojure-v]](project.clj)

[![][logo]][logo]


## About

This repo just contains utility and wrapper functions common to several CMR
projects which take advantage of http-kit's perfornance and the small size of
its library.


## Dependencies [&#x219F;](#contents)

* Java
* `lein`


## License [&#x219F;](#contents)

Copyright © 2018 NASA

Distributed under the Apache License, Version 2.0.


<!-- Named page links below: /-->

[logo]: https://avatars2.githubusercontent.com/u/32934967?s=200&v=4
[travis]: https://travis-ci.org/cmr-exchange/cmr-http-kit
[travis-badge]: https://travis-ci.org/cmr-exchange/cmr-http-kit.png?branch=master
[deps-badge]: https://img.shields.io/badge/deps%20check-passing-brightgreen.svg
[tag-badge]: https://img.shields.io/github/tag/cmr-exchange/cmr-http-kit.svg
[tag]: https://github.com/cmr-exchange/cmr-http-kit/tags
[clojure-v]: https://img.shields.io/badge/clojure-1.9.0-blue.svg
[clojars]: https://clojars.org/gov.nasa.earthdata/cmr-http-kit
[clojars-badge]: https://img.shields.io/clojars/v/gov.nasa.earthdata/cmr-http-kit.svg
[security-scan-badge]: https://img.shields.io/badge/dependency%20check%20security%20scan-passing-brightgreen.svg
[prs]: https://github.com/pulls?utf8=%E2%9C%93&q=is%3Aopen+is%3Apr+org%3Acmr-exchange+archived%3Afalse+
[prs-badge]: https://img.shields.io/badge/Open%20PRs-org-yellow.svg
